.\" @(#)ifftops.1 3.0 88/11/25 SRC;
.ds ]W \ 		\" overwrite the "Sun Release 3.5" string
.TH IFFTOPS 1 "25 November 1988"
.SH NAME
.in +10
.ti -10
ifftops \- translate an Amiga IFF format file into PostScript
.in -10
.SH SYNOPSIS
.I ifftops [-c] [-h] [-s] [-r <degrees>]
.ti +10
.I [-p <x-start>,<y-start>,<x-scale>,<y-scale>]
.ti +10
.I <input-file> [<output-file>]
.SH DESCRIPTION
.I Ifftops
translates Amiga IFF format files - specifically InterLeaved
BitMap (ILBM) graphics IFF files - into PostScript format.
It handles both black & white images and color images
(see NOTE #1 in NOTES section below), including HAM mode images.
There are options for positioning an image on the output page,
scaling the image (larger or smaller),
rotating the image,
and placing multiple images on the same output page.

The program works by generating a small PostScript-language
"header" followed by a hexadecimal representation (in ASCII),
of the bits of the image to render, in a raw format that
PostScript understands.
When the "header" is executed by the PostScript interpreter
(which is commonly embedded in the printer being used) it
handles the positioning, scaling, etc. functions and then
reads all of the following data to produce the resultant image.

All of the command line arguments are optional.
The one piece of information that
.I ifftops
needs is the name of the input file to process.
If this is not supplied on the command line then the user
is prompted for it.
(see NOTE #2)

The arguments to
.I ifftops
are:
.in +10
.ti -5
-c	color. Take a color ILBM IFF file and produce a
color PostScript output file.
(If this flag is used with a black & white ILBM IFF file then
the image is rendered in black & white with an interesting
sepia effect.)

.ti -5
-h	hold page image.
In PostScript terminology each printed page is called a page
image.
By default,
.I ifftops
appends a PostScript command at the end of each processed IFF
image to cause the current page image to print out.
If it is desired to place more than one IFF image onto the same
printed page (i.e. page image) then this flag will cause the
PostScript command (specifically "showpage")
not to be appended.
(see "EXAMPLES" below)

.ti -5
-s	smooth.
This flag is my own attempt (very unsophisticated and brute
force) at smoothing out the IFF image by doubling the number
of pixels, both horizontally and vertically, and averaging
the values.
(see NOTE #3 below)

.ti -5
-r	rotate.
Rotate the image by the given number of degrees.
The value for the degrees must be between 360 and -360.
Positive values result in counterclockwise rotation.

.ti -5
-p	position.
Place and size the IFF image within the PostScript page image
(i.e. on the resultant printed page.)
<x-start> and <y-start> are the PostScript coordinates of the
lower left-hand corner of the image to be printed.
The defaults for these are 10 and 10 respectively.
<x-scale> and <y-scale> are the PostScript dimensions, of the
image to be printed, in the x and y directions.
The defaults for these are 550 and 480 respectively.
(see "EXAMPLES" below)
.in -10

If an <output-file> is not specified on the command line then
the file "out.ps" is used.
If the specified (or default) <output-file> already exists then
the output is appended to the end of this file (this is so that
the "-h" flag (described above) will work.)
Be careful that this is what you want - it caused me trouble
on several occasions by appending to files when I didn't
intend to.
.SH EXAMPLES
Process the ILBM IFF format file named "dog" and put the resulting
PostScript output in the file "dog.ps":
.br
	ifftops dog dog.ps

Position and scale the image to be in the center of the page
and to be four inches by three inches:
.br
	ifftops -p 162,288,288,216 dog dog2.ps

Position, scale, and rotate the image so that there are four
copys of the image on the page, side-by-side, all four inches
by three inches:
.br
.nf
	ifftops -h -r 90 -p 306,396,288,216 dog dog3.ps
	ifftops -h -r 90 -p 522,396,288,216 dog dog3.ps
	ifftops -h -r 90 -p 306,108,288,216 dog dog3.ps
	ifftops -r 90 -p 522,108,288,216 dog dog3.ps
.fi
.SH NOTES
.in +5
.ti -5
1.)	The color PostScript syntax has only been tested on
a QMS Colorscript-100 printer.
Since color Postscript printers are rather new, and since the
PostScript syntax for handling color images has not yet been
standardized, there is a good chance that the output generated
by this program will not work on printers built by other
manufacturers.
The source code contains preprocessor statements (i.e.
"#define QMS") which surround the color PostScript specific
lines so, hopefully, it should be straight-forward to add
support for other manufacturers' printers, if it is necessary.

.ti -5
2.)	All of the code development for this program was done
on a Sun system running SunOS (i.e. UNIX) for the fairly weak
reason that I did not have a compiler for my Amiga at that
time (also, the only PostScript printers that I had access to
were available via the Sun.)
Therefore, I have made sure that the code compiles under both
UNIX and AmigaDOS.
The source code contains preprocessor statements to toggle
the differences between the two environments (mostly "#include"
files and some "#define"s).
To compile this program for one of the two environments either
a "#define AMIGA" or a "#define UNIX" must exist at the
beginning of the file.
Be sure that ONLY ONE of these two "#define"s is in effect.

.ti -5
3.)	The "-s" flag has very little noticeable effect on a 300 DPI
laser printer.
I believe that this is because the default "print cell" size is
approximately 50 cells per inch.
On the QMS Colorscript-100 printer I prepended the following
PostScript code, by hand, to the output file produced by
.I ifftops:
.in +6
.nf
%!
/sfreq 72 def
/sproc {dup mul exch dup mul add 1 exch sub} def
sfreq 60 /sproc load
sfreq 30 /sproc load
sfreq 0 /sproc load
sfreq 0 /sproc load
setcolorscreen
.fi
.in
(NOTE: this printer is a four-color printer (YMCB))
.br
(NOTE: the standard PostScript language has a counterpart "setscreen"
command for black & white printers.)
.br
The result of adding these lines was a noticeable reduction in the
grainyness of the output file.

An unfortunate side effect of this smoothing function is an aprox.
40% increase in the size of the source code file.
(I haven't check the relative sizes of the binary files.)
Because of this and because of its marginal usefulness, the source code
includes preprocessor defines, keyed on the identifier SMOOTH_INCLUDE,
which allow the smoothing code to be compiled out of the program.
Specifically, if the line "#define SMOOTH_INCLUDE" exists in the
source file then the smoothing code will be included.

Happily, the smoothing function only adds a small amount to the total
execution time of the program.
However, the user should take note that using the "-s" flag causes
the output file to be four times larger that it would be without using
this flag.
.in -5
.SH FILES
.nf
.ta 20
out.ps	default output file if none is specified
.ta 8
.fi
.\".SH SEE ALSO
.\"adduser(1), /etc/data/README, passwd(5)
.SH BUGS
There should be a way for the <input-file> and <output-file> to
be re-directed from/to standard-input and standard-output.
.SH AUTHOR
LeRoy Fundingsland, November 1988
.br
(derived from a program called CLAZ which was created by
Steve Ludtke, May 1987)
